==> opensubdiv-3.6.0-1-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/functions_5.js <==
var searchData=
[
  ['facehaslimitsurface_0',['FaceHasLimitSurface',['../a00941.html#a5cab9f649e56c15a486e3878a19bedf7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::SurfaceFactory']]],
  ['faceweight_1',['FaceWeight',['../a01345.html#a674da1128895a8cbafa6c0ec49e9aec0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::FaceWeight(int index) const'],['../a01345.html#aedf29f30786b62372004a22a3fa35a5c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::FaceWeight(int index)']]],
  ['finalize_2',['finalize',['../a01061.html#a32d626626eee0bc4ade146973f6abb1c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilTableReal']]],
  ['finalize_3',['Finalize',['../a00969.html#a0cb0c1f4fa225637898cf1c7420bc064',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::VertexDescriptor']]],
  ['findbaseedge_4',['findBaseEdge',['../a01117.html#abadf245d872a6a226772a14a471324d0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['findedge_5',['FindEdge',['../a01113.html#a9197cce11b83fae9f8ed3ef5ac79c2ed',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel']]],
  ['findindex_6',['FindIndex',['../a01353.html#aab75dd5fb27049f92ee6af282b29be8c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray']]],
  ['findindexin4tuple_7',['FindIndexIn4Tuple',['../a01353.html#a5afd472f9e68f5d28798ef5953a995a1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray']]],
  ['findpatch_8',['FindPatch',['../a00977.html#abc70f9419d5f26ef85cbef5c5b6451f0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchMap']]],
  ['fvarchannel_9',['FVarChannel',['../a01109.html#a029d281df9f5dc8c00b52a35f8e0dfde',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor::FVarChannel']]]
];

==> opensubdiv-3.6.0-2-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/search/functions_5.js <==
var searchData=
[
  ['facehaslimitsurface_0',['FaceHasLimitSurface',['../a00941.html#a5cab9f649e56c15a486e3878a19bedf7',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::SurfaceFactory']]],
  ['faceweight_1',['FaceWeight',['../a01345.html#a674da1128895a8cbafa6c0ec49e9aec0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::FaceWeight(int index) const'],['../a01345.html#aedf29f30786b62372004a22a3fa35a5c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Sdc::Scheme::LocalMask::FaceWeight(int index)']]],
  ['finalize_2',['Finalize',['../a00969.html#a0cb0c1f4fa225637898cf1c7420bc064',1,'OpenSubdiv::OPENSUBDIV_VERSION::Bfr::VertexDescriptor']]],
  ['finalize_3',['finalize',['../a01061.html#a32d626626eee0bc4ade146973f6abb1c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::StencilTableReal']]],
  ['findbaseedge_4',['findBaseEdge',['../a01117.html#abadf245d872a6a226772a14a471324d0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyRefinerFactory']]],
  ['findedge_5',['FindEdge',['../a01113.html#a9197cce11b83fae9f8ed3ef5ac79c2ed',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyLevel']]],
  ['findindex_6',['FindIndex',['../a01353.html#aab75dd5fb27049f92ee6af282b29be8c',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray']]],
  ['findindexin4tuple_7',['FindIndexIn4Tuple',['../a01353.html#a5afd472f9e68f5d28798ef5953a995a1',1,'OpenSubdiv::OPENSUBDIV_VERSION::Vtr::ConstArray']]],
  ['findpatch_8',['FindPatch',['../a00977.html#abc70f9419d5f26ef85cbef5c5b6451f0',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::PatchMap']]],
  ['fvarchannel_9',['FVarChannel',['../a01109.html#a029d281df9f5dc8c00b52a35f8e0dfde',1,'OpenSubdiv::OPENSUBDIV_VERSION::Far::TopologyDescriptor::FVarChannel']]]
];
